@@ -3,10 +3,58 @@ import requests
 from .Action import Action
 from .Image import Image
 from .Kernel import Kernel
-from .baseapi import BaseAPI
+from .baseapi import BaseAPI, Error
 from .SSHKey import SSHKey
 
+class DropletError(Error):
+    """Base exception class for this module"""
+    pass
+
+class BadKernelObject(DropletError):
+    pass
+
+class BadSSHKeyFormat(DropletError):
+    pass
+
 class Droplet(BaseAPI):
+    """"Droplet managment
+
+    Attributes accepted at creation time:
+        name: str - name
+        size_slug: str - droplet size
+        image: str - image name to use to create droplet
+        region: str - region
+        ssh_keys: [str] - list of ssh keys
+        backups: bool - True if backups enabled
+        ipv6: bool - True if ipv6 enabled
+        private_networking: bool - True if private networking enabled
+        user_data: str - arbitrary data to pass to droplet
+
+    Attributes returned by API:
+        id: int - droplet id
+        memory: str - memory size
+        vcpus: int - number of vcpus
+        disk: int - disk size in GB
+        status: str - status
+        locked: bool - True if locked
+        created_at: str - creation date in format u'2014-11-06T10:42:09Z'
+        status: str - status, e.g. 'new', 'active', etc
+        networks: dict - details of connected networks
+        kernel: dict - details of kernel
+        backup_ids: [int] - list of ids of backups of this droplet
+        snapshot_ids: [int] - list of ids of snapshots of this droplet
+        action_ids: [int] - list of ids of actions
+        features: [str] - list of enabled features. e.g.
+                  [u'private_networking', u'virtio']
+        min_size: str - minumum size of droplet that can bew created from a
+                   snapshot of this droplet
+        image: dict - details of image used to create this droplet
+        ip_address: str - public ip addresses
+        private_ip_address: str - private ip address
+        ip_v6_address: [str] - list of ipv6 addresses assigned
+        end_point: str - url of api endpoint used
+    """
+
     def __init__(self, *args, **kwargs):
         # Defining default values
         self.id = None
@@ -41,8 +89,11 @@ class Droplet(BaseAPI):
 
     @classmethod
     def get_object(cls, api_token, droplet_id):
-        """
-            Class method that will return a Droplet object by ID.
+        """Class method that will return a Droplet object by ID.
+
+        Args:
+            api_token: str - token
+            droplet_id: int - droplet id
         """
         droplet = cls(token=api_token, id=droplet_id)
         droplet.load()
@@ -66,6 +117,9 @@ class Droplet(BaseAPI):
         return data
 
     def load(self):
+        """
+           Fetch data about droplet - use this instead of get_data()
+        """
         droplets = self.get_data("droplets/%s" % self.id)
         droplet = droplets['droplet']
 
@@ -142,8 +196,10 @@ class Droplet(BaseAPI):
         )
 
     def resize(self, new_size_slug):
-        """
-            resize the droplet to a new size slug.
+        """Resize the droplet to a new size slug.
+
+        Args:
+            new_size_slug: str - name of new size
         """
         return self.get_data(
             "droplets/%s/actions/" % self.id,
@@ -152,8 +208,10 @@ class Droplet(BaseAPI):
         )
 
     def take_snapshot(self, snapshot_name):
-        """
-            Take a snapshot!
+        """Take a snapshot!
+
+        Args:
+            snapshot_name: str - name of snapshot
         """
         return self.get_data(
             "droplets/%s/actions/" % self.id,
@@ -162,8 +220,10 @@ class Droplet(BaseAPI):
         )
 
     def restore(self, image_id):
-        """
-            Restore the droplet to an image ( snapshot or backup )
+        """Restore the droplet to an image ( snapshot or backup )
+
+        Args:
+            image_id : int - id of image
         """
         return self.get_data(
             "droplets/%s/actions/" % self.id,
@@ -172,8 +232,10 @@ class Droplet(BaseAPI):
         )
 
     def rebuild(self, image_id=None):
-        """
-            Restore the droplet to an image ( snapshot or backup )
+        """Restore the droplet to an image ( snapshot or backup )
+
+        Args:
+            image_id : int - id of image
         """
         if self.image_id and not image_id:
             image_id = self.image_id
@@ -210,8 +272,10 @@ class Droplet(BaseAPI):
         )
 
     def rename(self, name):
-        """
-            Rename the droplet
+        """Rename the droplet
+
+        Args:
+            name : str - new name
         """
         return self.get_data(
             "droplets/%s/actions/" % self.id,
@@ -240,11 +304,13 @@ class Droplet(BaseAPI):
         )
 
     def change_kernel(self, kernel):
-        """
-            Change the kernel to a new one
+        """Change the kernel to a new one
+
+        Args:
+            kernel : instance of digitalocean.Kernel.Kernel
         """
         if type(kernel) != Kernel:
-            raise Exception("Use Kernel object")
+            raise BadKernelObject("Use Kernel object")
 
         return self.get_data(
             "droplets/%s/actions/" % self.id,
@@ -280,7 +346,7 @@ class Droplet(BaseAPI):
 
                 ssh_keys_id.append(key.id)
             else:
-                raise Exception("Droplet.ssh_keys should be a list of IDs or public keys")
+                raise BadSSHKeyFormat("Droplet.ssh_keys should be a list of IDs or public keys")
 
         return ssh_keys_id
 
@@ -355,8 +421,10 @@ class Droplet(BaseAPI):
         return actions
 
     def get_action(self, action_id):
-        """
-            Returns a specific Action by its ID.
+        """Returns a specific Action by its ID.
+
+        Args:
+            action_id: int - id of action
         """
         return Action.get_object(
             api_token=self.token,
